@@ -6,7 +6,7 @@ use Webqq::Encryption::TEA;
 use Webqq::Encryption::RSA;
 our @EXPORT_OK = qw(pwd_encrypt pwd_encrypt_js);
 
-our $VERSION = "1.5";
+our $VERSION = "1.6";
 
 BEGIN{
     eval{require JE;};
@@ -19,19 +19,24 @@ sub pwd_encrypt{
     $pwd = md5_hex($pwd) if $is_md5_pwd == 0; 
 
     $md5_salt = eval qq{"$md5_salt"};
-    my $h1 = pack "H*",lc $pwd;
-    my $s2 = md5_hex($h1 . $md5_salt)  ;
-    my $rsaH1= Webqq::Encryption::RSA::encrypt($h1);
-    my $rsaH1Len = sprintf "%x",length($rsaH1)/2;
-    my $hexVcode = Webqq::Encryption::TEA::strToHex(uc $verifycode);
-    my $vcodeLen = "000" . sprintf("%x",length($verifycode));
-    while(length($rsaH1Len) < 4){
-        $rsaH1Len = "0" . $rsaH1Len;
-    }   
+    my $r = pack "H*",lc $pwd;
+    my $s = md5_hex($r . $md5_salt);
     
-    my $saltPwd = Webqq::Encryption::TEA::encrypt($s2,$rsaH1Len . $rsaH1 . Webqq::Encryption::TEA::strToHex($md5_salt) . $vcodeLen . $hexVcode);
-    $saltPwd =~ tr/\/\+=/-*_/;
-    return $saltPwd;
+    my $a = Webqq::Encryption::TEA::strToHex(uc $verifycode);
+    my $l = sprintf "%x",length($a)/2;
+    while(length($l)<4){
+        $l = "0" . $l;
+    }
+    my $c = Webqq::Encryption::TEA::encrypt($s,$pwd . Webqq::Encryption::TEA::strToHex($md5_salt) . $l . $a );
+    my $u = sprintf "%x",length($c)/2;
+    while(length($u)<4){
+        $u =  "0" . $u;
+    }
+
+    my $h = Webqq::Encryption::RSA::encrypt( pack "H*",$u . $c );
+    $h = MIME::Base64::encode_base64(pack("H*",$h),"");
+    $h =~ tr/\/\+=/-*_/;
+    return $h;
 }
 
 sub pwd_encrypt_js {
@@ -1277,8 +1282,8 @@ function __RSA() {
     }
     var M = 256;
     function S(aB, aA, z) {
-        aA = "F20CE00BAE5361F8FA3AE9CEFA495362FF7DA1BA628F64A347F0A8C012BF0B254A30CD92ABFFE7A6EE0DC424CB6166F8819EFA5BCCB20EDFB4AD02E412CCF579B1CA711D55B8B0B3AEB60153D5E0693A2A86F3167D7847A0CB8B00004716A9095D9BADC977CBB804DBDCBA6029A9710869A453F27DFDDF83C016D928B3CBF4C7";
-        z = "3";
+        aA = "e9a815ab9d6e86abbf33a4ac64e9196d5be44a09bd0ed6ae052914e1a865ac8331fed863de8ea697e9a7f63329e5e23cda09c72570f46775b7e39ea9670086f847d3c9c51963b131409b1e04265d9747419c635404ca651bbcbc87f99b8008f7f5824653e3658be4ba73e4480156b390bb73bc1f8b33578e7a4e12440e9396f2552c1aff1c92e797ebacdc37c109ab7bce2367a19c56a033ee04534723cc2558cb27368f5b9d32c04d12dbd86bbd68b1d99b7c349a8453ea75d1b2e94491ab30acf6c46a36a75b721b312bedf4e7aad21e54e9bcbcf8144c79b6e3c05eb4a1547750d224c0085d80e6da3907c3d945051c13c7c1dcefd6520ee8379c4f5231ed";
+        z = "10001";
         var t = new L();
         t.setPublic(aA, z);
         return t.encrypt(aB)
@@ -1497,30 +1502,23 @@ $.Encryption = function() {
         s.src = url;
         s = null
     }
-    function getEncryption(password, salt, vcode, isMd5) {
-        vcode = vcode || "";
-        password = password || "";
-        var md5Pwd = isMd5 ? password: md5(password),
-        h1 = hexchar2bin(md5Pwd),
-        s2 = md5(h1 + salt),
-        rsaH1 = $.RSA.rsa_encrypt(h1),
-        rsaH1Len = (rsaH1.length / 2).toString(16),
-        hexVcode = TEA.strToBytes(vcode.toUpperCase()),
-        vcodeLen = "000" + vcode.length.toString(16);
-        while (rsaH1Len.length < 4) {
-            rsaH1Len = "0" + rsaH1Len
-        }
-        TEA.initkey(s2);
-        var saltPwd = window.TEA.enAsBase64(rsaH1Len + rsaH1 + TEA.strToBytes(salt) + vcodeLen + hexVcode);
+    function getEncryption(e, i, n, o) {
+        n = n || "",
+        e = e || "";
+        for (var p = o ? e : md5(e), r = hexchar2bin(p), s = md5(r + i), a = TEA.strToBytes(n.toUpperCase()), l = Number(a.length / 2).toString(16); l.length < 4; )
+            l = "0" + l;
+        TEA.initkey(s);
+        var c = TEA.encrypt(p + TEA.strToBytes(i) + l + a);
         TEA.initkey("");
-        //__monitor(488358, 1);
-        return saltPwd.replace(/[\/\+=]/g,
-        function(a) {
+        for (var u = Number(c.length / 2).toString(16); u.length < 4; )
+            u = "0" + u;
+        var h = $.RSA.rsa_encrypt(hexchar2bin(u + c));
+        window.btoa(hexchar2bin(h)).replace(/[\/\+=]/g, function(t) {
             return {
                 "/": "-",
                 "+": "*",
                 "=": "_"
-            } [a]
+            }[t]
         })
     }
     function getRSAEncryption(password, vcode, isMd5) {
